/**
 * Define digest function.
 * @function defineDigest
 */

"use strict";

const apemanpasswd = require('apemanpasswd'),
    Promise = require('apemanpromise'),
    async = require('async');

const DEFAULT_SPEC = [
    apemanpasswd.DEFAULT_ALGORITHM,
    apemanpasswd.DEFAULT_ITERATIONS,
    apemanpasswd.DEFAULT_LENGTH
].join(':');

/** @lends defineDigest */
function defineDigest(spec) {
    let passwd = apemanpasswd.fromSpecString(spec || DEFAULT_SPEC);

    function digest(password, salt) {
        return new Promise((resolve, reject) => {
            passwd.digest(password, salt, (err, hash) => {
                if (err) {
                    reject(err);
                } else {
                    resolve(hash);
                }
            });
        });
    }

    digest.newSalt = passwd.newSalt.bind(passwd);
    return digest;
}

module.exports = defineDigest;
