/**
 * @function doSignmod
 * @returns Promise
 */

"use strict";

const Promise = require('apemanpromise'),
    doSignget = require('./do_signget');

/** @lends doSignmod */
function doSignmod(User, Sign, data, digest, signed) {
    return User.findById(signed.user.id)
        .then(user => {
            if (!user) {
                return null;
            }
            return Sign.findAll({
                    where: {user_id: user.get('id')}
                })
                .then(signs =>
                    Promise.all(
                        signs.map(sign => {
                            let password = data.password;
                            if (!password) {
                                return sign;
                            }
                            return digest(password, sign.password_salt)
                                .then(hash =>
                                    sign.update({
                                        password_hash: hash,
                                        signmod_at: new Date()
                                    })
                                )
                        })
                    )
                )
                .then(() => {
                    delete data.password;
                    return user.update(data);
                })
        })
        .then(user =>
            doSignget(User, Sign, signed)
        );
}

module.exports = doSignmod;

