/**
 * @function doSignup
 * @returns Promise
 */
"use strict";

const Promise = require('apemanpromise'),
    doSignget = require('./do_signget');

/** @lends doSignup */
function doSignup(User, Sign, data, digest, signKeys, saltLength) {
    let salt = digest.newSalt(saltLength || 24);
    return digest(data.password, salt)
        .then(hash => {
            let user = Object.assign(data);
            delete user.password;
            return User.create(user)
                .then(user =>
                    Promise.all(
                        signKeys.map(signKey =>
                            Sign.create({
                                user_id: user.get('id'),
                                sign_key_kind: signKey,
                                sign_key: data[signKey],
                                password_salt: salt,
                                password_hash: hash,
                                signup_at: new Date()
                            })
                        )
                    )
                )
        })
        .then(signs =>
            signs.map(sign => doSignget(User, Sign, sign))
        );
}

module.exports = doSignup;
